==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/datagen/tag/EntityTagProvider.java <==
package cc.thonly.reverie_dreams.datagen.tag;

import cc.thonly.reverie_dreams.registry.tag.RDEntityTypeTags;
import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import cc.thonly.reverie_dreams.registry.RegistryHandlers;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_11389;
import net.minecraft.class_1299;
import net.minecraft.class_3483;
import net.minecraft.class_7225;
import java.util.concurrent.CompletableFuture;

public class EntityTagProvider extends FabricTagProvider.EntityTypeTagProvider {

    public EntityTagProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
        super(output, registriesFuture);
    }

    @Override
    protected void method_10514(class_7225.class_7874 wrapperLookup) {
        class_11389<class_1299<?>, class_1299<?>> roleBuilder = valueLookupBuilder(RDEntityTypeTags.NPC_ROLE);

        RegistryHandlers.NPC_ROLE.values().forEach(role -> roleBuilder.method_71554(role.getEntityType()));

        class_11389<class_1299<?>, class_1299<?>> undead = valueLookupBuilder(class_3483.field_46232);
        undead.method_71554(RDEntityTypes.GHOST_ENTITY_TYPE);

        class_11389<class_1299<?>, class_1299<?>> yokai = valueLookupBuilder(RDEntityTypeTags.YOKAI);
        yokai.method_71554(RDEntityTypes.MAID_YOUSEI_ENTITY_TYPE);
        yokai.method_71554(RDEntityTypes.SUNFLOWER_YOUSEI_ENTITY_TYPE);
        yokai.method_71554(RDEntityTypes.YOUSEI_ENTITY_TYPE);
        yokai.method_71554(RDEntityTypes.HAIRBALL_ENTITY_TYPE);
        yokai.method_71554(RDEntityTypes.GHOST_ENTITY_TYPE);
        yokai.method_71554(RDEntityTypes.MUSHROOM_MONSTER_ENTITY_TYPE);
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/datagen/tag/EntityTagProvider.java <==
package cc.thonly.reverie_dreams.datagen.tag;

import cc.thonly.reverie_dreams.registry.RegistryHandlers;
import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import cc.thonly.reverie_dreams.registry.tag.RDEntityTypeTags;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_11389;
import net.minecraft.class_1299;
import net.minecraft.class_3483;
import net.minecraft.class_7225;
import java.util.concurrent.CompletableFuture;

public class EntityTagProvider extends FabricTagProvider.EntityTypeTagProvider {

    public EntityTagProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
        super(output, registriesFuture);
    }

    @Override
    protected void method_10514(class_7225.class_7874 wrapperLookup) {
        class_11389<class_1299<?>, class_1299<?>> roleBuilder = valueLookupBuilder(RDEntityTypeTags.NPC_ROLE);

        RegistryHandlers.NPC_ROLE.values().forEach(role -> roleBuilder.method_71554(role.getEntityType()));

        class_11389<class_1299<?>, class_1299<?>> undead = valueLookupBuilder(class_3483.field_46232);
        undead.method_71554(RDEntityTypes.GHOST);

        class_11389<class_1299<?>, class_1299<?>> yokai = valueLookupBuilder(RDEntityTypeTags.YOKAI);
        yokai.method_71554(RDEntityTypes.MAID_YOUSEI);
        yokai.method_71554(RDEntityTypes.SUNFLOWER_YOUSEI);
        yokai.method_71554(RDEntityTypes.YOUSEI);
        yokai.method_71554(RDEntityTypes.HAIRBALL);
        yokai.method_71554(RDEntityTypes.GHOST);
        yokai.method_71554(RDEntityTypes.MUSHROOM_MONSTER);
    }
}
